@@ -1,7 +1,7 @@
 #' Table of Densities, Function of Temperature for Fixed Pressure
 #'
 #' @description The function \code{DTpcteTab(T1, T2, dT, p)} returns a table of 
-#'     densities [kg m-3] for a fixed p [MPa] within a range of T [K]: T1:T2 [K].
+#'     densities [kg m-3] for a fixed p [MPa] within a range of Temp [K]: T1:T2 [K].
 #'
 #' @details This function calls a Fortran DLL that solves the Helmholtz Energy Equation. 
 #'     in accordance with the Revised Release on the IAPWS Formulation 1995 for the 
@@ -54,7 +54,7 @@ DTpcteTab <- function(T1, T2, dT, p) {
 #' Table of Enthalpies, Function of Temperature and Fixed Pressure
 #'
 #' @description The function \code{hTpcteTab(T1, T2, dT, p)} returns a table of 
-#'     enthalpies [kJ kg-1] for a fixed p [MPa] within a range of T [K]: T1:T2 [K]
+#'     enthalpies [kJ kg-1] for a fixed p [MPa] within a range of Temp [K]: T1:T2 [K]
 #'
 #' @details This function calls a Fortran DLL that solves the Helmholtz Energy Equation. 
 #'     in accordance with the Revised Release on the IAPWS Formulation 1995 for the 
@@ -159,10 +159,10 @@ sTpcteTab <- function(T1, T2, dT, p) {
 
 #' Table of Densities, Function of Pressure for a Fixed Temperature
 #'
-#' This function provides a table of the densities [kg m-3] for a given T [K] within a range of p [MPa]
+#' This function provides a table of the densities [kg m-3] for a given Temp [K] within a range of p [MPa]
 #'
-#' @description The function \code{DpTcteTab(p1, p2, dp, T)} returns a table of 
-#'     Densities [kg m-3] for a fixed T [K] within a range of p [MPa]: p1:p2 [MPa]
+#' @description The function \code{DpTcteTab(p1, p2, dp, Temp)} returns a table of 
+#'     Densities [kg m-3] for a fixed Temp [K] within a range of p [MPa]: p1:p2 [MPa]
 #'
 #' @details This function calls a Fortran DLL that solves the Helmholtz Energy Equation. 
 #'     in accordance with the Revised Release on the IAPWS Formulation 1995 for the 
@@ -174,7 +174,7 @@ sTpcteTab <- function(T1, T2, dT, p) {
 #' @param p1 first pressure value [ MPa ]
 #' @param p2 final pressure [ MPa ]
 #' @param dp Pressure increment [ MPa ]
-#' @param T Temperature [ K ]
+#' @param Temp Temperature [ K ]
 #' 
 #' @return A table of Densities for fixed T and a p Interval: p1:p2.
 #' 
@@ -182,20 +182,20 @@ sTpcteTab <- function(T1, T2, dT, p) {
 #' p1 <- 1.0
 #' p2 <- 10.
 #' dp <- 1.
-#' T <- 500.
-#' TabD <- DpTcteTab(p1, p2, dp, T)
+#' Temp <- 500.
+#' TabD <- DpTcteTab(p1, p2, dp, Temp)
 #' TabD
 #' 
 #' p1 <- 10.
 #' p2 <- 100.
 #' dp <- 10.
-#' T <- 450.
-#' TabD <- DpTcteTab(p1, p2, dp, T)
+#' Temp <- 450.
+#' TabD <- DpTcteTab(p1, p2, dp, Temp)
 #' TabD
 #' 
 #' @export
 #' 
-DpTcteTab <- function(p1, p2, dp, T) {
+DpTcteTab <- function(p1, p2, dp, Temp) {
   pv <- seq(from=p1,  to=p2, by=dp)
   n  <- length(pv)
   y  <- seq(from=1., to=n, by=1.)
@@ -203,19 +203,19 @@ DpTcteTab <- function(p1, p2, dp, T) {
   y[,2] <- y[,1]
   y <- as.matrix(y)
   icode <- 0
-  res <- .Fortran('DpTcteTab', as.integer(n), T, pv, y)
+  res <- .Fortran('DpTcteTab', as.integer(n), Temp, pv, y)
   
   DTab <- as.data.frame(res[[4]])
-  DTab$T<- rep(T,nrow(DTab))
+  DTab$Temp<- rep(Temp,nrow(DTab))
   DTab <- DTab[,c(3,1,2)]
-  colnames(DTab) <- c("T [K]", "p [K]", "D [kg m-3]")
+  colnames(DTab) <- c("Temp [K]", "p [K]", "D [kg m-3]")
   return(DTab)
 }
 
 #' Table of Enthalpies, Function of Pressure for Fixed Temperature
 #'
-#' @description The function \code{hpTcteTab(p1, p2, dp, T)} returns a table of 
-#'     Enthalpies [kJ kg-1] for a fixed T [K] within a range of p [MPa]: p1:p2 [MPa]
+#' @description The function \code{hpTcteTab(p1, p2, dp, Temp)} returns a table of 
+#'     Enthalpies [kJ kg-1] for a fixed Temp [K] within a range of p [MPa]: p1:p2 [MPa]
 #'
 #' @details This function calls a Fortran DLL that solves the Helmholtz Energy Equation. 
 #'     in accordance with the Revised Release on the IAPWS Formulation 1995 for the 
@@ -227,7 +227,7 @@ DpTcteTab <- function(p1, p2, dp, T) {
 #' @param p1 first pressure value [ MPa ]
 #' @param p2 final pressure [ MPa ]
 #' @param dp Pressure increment [ MPa ]
-#' @param T Temperature [ K ]
+#' @param Temp Temperature [ K ]
 #' 
 #' @return A table of Enthalpies for fixed T and a p Interval: p1:p2.
 #' 
@@ -235,20 +235,20 @@ DpTcteTab <- function(p1, p2, dp, T) {
 #' p1 <- 1.0
 #' p2 <- 10.
 #' dp <- 1.
-#' T <- 500.
-#' Tabh <- hpTcteTab(p1, p2, dp, T)
+#' Temp <- 500.
+#' Tabh <- hpTcteTab(p1, p2, dp, Temp)
 #' Tabh
 #' 
 #' p1 <- 10.
 #' p2 <- 100.
 #' dp <- 10.
-#' T <- 450.
-#' Tabh <- hpTcteTab(p1, p2, dp, T)
+#' Temp <- 450.
+#' Tabh <- hpTcteTab(p1, p2, dp, Temp)
 #' Tabh
 #' 
 #' @export
 #' 
-hpTcteTab <- function(p1, p2, dp, T) {
+hpTcteTab <- function(p1, p2, dp, Temp) {
   pv <- seq(from=p1,  to=p2, by=dp)
   n  <- length(pv)
   y  <- seq(from=1., to=n, by=1.)
@@ -256,19 +256,19 @@ hpTcteTab <- function(p1, p2, dp, T) {
   y[,2] <- y[,1]
   y <- as.matrix(y)
   icode <- 0
-  res <- .Fortran('hpTcteTab', as.integer(n), T, pv, y)
+  res <- .Fortran('hpTcteTab', as.integer(n), Temp, pv, y)
   
   hTab <- as.data.frame(res[[4]])
-  hTab$T<- rep(T,nrow(hTab))
+  hTab$Temp<- rep(Temp,nrow(hTab))
   hTab <- hTab[,c(3,1,2)]
-  colnames(hTab) <- c("T [K]", "p [K]", "h [kJ kg-1]")
+  colnames(hTab) <- c("Temp [K]", "p [K]", "h [kJ kg-1]")
   return(hTab)
 }
 
 #' Table of Entropies, Function of Pressure for Fixed Temperature
 #'
-#' @description The function \code{spTcteTab(p1, p2, dp, T)} returns a table of 
-#'     Entropies [kJ kg-1 K-1] for a fixed T [K] within a range of p [MPa]: p1:p2 [MPa]
+#' @description The function \code{spTcteTab(p1, p2, dp, Temp)} returns a table of 
+#'     Entropies [kJ kg-1 K-1] for a fixed Temp [K] within a range of p [MPa]: p1:p2 [MPa]
 #'
 #' @details This function calls a Fortran DLL that solves the Helmholtz Energy Equation. 
 #'     in accordance with the Revised Release on the IAPWS Formulation 1995 for the 
@@ -280,28 +280,28 @@ hpTcteTab <- function(p1, p2, dp, T) {
 #' @param p1 "initial"first pressure value [ MPa ]
 #' @param p2 final pressure [ MPa ]
 #' @param dp Pressure increment [ MPa ]
-#' @param T Temperature [ K ]
+#' @param Temp Temperature [ K ]
 #' 
-#' @return A table of Entropies for fixed T and a p Interval: p1:p2.
+#' @return A table of Entropies for fixed Temp and a p Interval: p1:p2.
 #' 
 #' @examples
 #' p1 <- 1.0
 #' p2 <- 10.
 #' dp <- 1.
-#' T <- 500.
-#' Tabs <- spTcteTab(p1, p2, dp, T)
+#' Temp <- 500.
+#' Tabs <- spTcteTab(p1, p2, dp, Temp)
 #' Tabs
 #' 
 #' p1 <- 10.
 #' p2 <- 100.
 #' dp <- 10.
-#' T <- 450.
-#' Tabs <- spTcteTab(p1, p2, dp, T)
+#' Temp <- 450.
+#' Tabs <- spTcteTab(p1, p2, dp, Temp)
 #' Tabs
 #' 
 #' @export
 #' 
-spTcteTab <- function(p1, p2, dp, T) {
+spTcteTab <- function(p1, p2, dp, Temp) {
   pv <- seq(from=p1,  to=p2, by=dp)
   n  <- length(pv)
   y  <- seq(from=1., to=n, by=1.)
@@ -309,11 +309,11 @@ spTcteTab <- function(p1, p2, dp, T) {
   y[,2] <- y[,1]
   y <- as.matrix(y)
   icode <- 0
-  res <- .Fortran('spTcteTab', as.integer(n), T, pv, y)
+  res <- .Fortran('spTcteTab', as.integer(n), Temp, pv, y)
   
   sTab <- as.data.frame(res[[4]])
   sTab$T<- rep(T,nrow(sTab))
   sTab <- sTab[,c(3,1,2)]
-  colnames(sTab) <- c("T [K]", "p [K]", "s [kJ kg-1 K-1]")
+  colnames(sTab) <- c("Temp [K]", "p [K]", "s [kJ kg-1 K-1]")
   return(sTab)
 }
